aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/ADT/Triple.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/ADT/Triple.h')
-rw-r--r--include/llvm/ADT/Triple.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/llvm/ADT/Triple.h b/include/llvm/ADT/Triple.h
index 2f427c02dd..4cfad31df5 100644
--- a/include/llvm/ADT/Triple.h
+++ b/include/llvm/ADT/Triple.h
@@ -266,15 +266,15 @@ public:
return false;
}
/// isOSX - Is this an OS X triple. For legacy reasons, we support both
/// "darwin" and "osx" as OS X triples.
- bool isOSX() const {
+ bool isMacOSX() const {
return getOS() == Triple::Darwin || getOS() == Triple::MacOSX;
}
/// isOSDarwin - Is this a "Darwin" OS (OS X or iOS).
bool isOSDarwin() const {
- return isOSX() ||getOS() == Triple::IOS;
+ return isMacOSX() ||getOS() == Triple::IOS;
}
/// isOSWindows - Is this a "Windows" OS.
@@ -283,12 +283,12 @@ public:
getOS() == Triple::MinGW32;
}
/// isOSXVersionLT - Comparison function for checking OS X version
/// compatibility, which handles supporting skewed version numbering schemes
/// used by the "darwin" triples.
- unsigned isOSXVersionLT(unsigned Major, unsigned Minor = 0,
+ unsigned isMacOSXVersionLT(unsigned Major, unsigned Minor = 0,
unsigned Micro = 0) const {
- assert(isOSX() && "Not an OS X triple!");
+ assert(isMacOSX() && "Not an OS X triple!");
// If this is OS X, expect a sane version number.
if (getOS() == Triple::MacOSX)
@@ -266,15 +266,15 @@ public:
return false;
}
- /// isOSX - Is this an OS X triple. For legacy reasons, we support both
+ /// isMacOSX - Is this a Mac OS X triple. For legacy reasons, we support both
/// "darwin" and "osx" as OS X triples.
@@ -283,12 +283,12 @@ public:
getOS() == Triple::MinGW32;
}
- /// isOSXVersionLT - Comparison function for checking OS X version
+ /// isMacOSXVersionLT - Comparison function for checking OS X version
/// compatibility, which handles supporting skewed version numbering schemes
/// used by the "darwin" triples.